/***************************************************************************
                          resource.h  -  description
                          --------------------------
    copyright            : (C) 2000 by Torsten Henschel
    email                : thenschel@henschelsoft.de
 ***************************************************************************/

/***************************************************************************
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

#ifndef RESOURCE_H
#define RESOURCE_H

#ifdef HAVE_CONFIG_H
#include <config.h>
#endif

// COMMAND VALUES FOR MENUBAR AND TOOLBAR ENTRIES


// Define generic command codes
#define ID_EXIT                 100
#define ID_NEW_POPUP            120
#define ID_ANSWER_POPUP         140
#define ID_STATUS_TEXT          160
#define ID_HELP                 180
#define ID_PREVIOUS_POPUP       200
#define ID_NEXT_POPUP           220
#define ID_DELETE_POPUP         240
#define ID_MIN_POPUP            260

#endif
